#!/usr/bin/env node

const argv = require('yargs').argv
const rp = require('request-promise-native');
const fs = require('fs');
const { exec } = require("child_process");

const manifest = JSON.parse(fs.readFileSync("package.json").toString());

const publish = async () => {
    const body = JSON.stringify({
        version: manifest.version,
        artifactName: manifest.name,
        slackChannel: argv.slackChannel || process.env.DAD_SLACK_CHANNEL,
        teamName: argv.teamName || process.env.DAD_TEAM_NAME,
        environmentName: argv.stage,
        repositoryName: process.env.BITBUCKET_REPO_FULL_NAME,
        message: await getLatestCommitMessage(),
    });

    console.log(body);

    const url = process.env[`DAD_URL_${argv.stage.toUpperCase()}`]

    await rp.post(url, { body })
};

const getLatestCommitMessage = async () => {
    const exec_cmd = `git log --format=%B -n 1 ${process.env.BITBUCKET_COMMIT}`;

    return new Promise((resolve, reject) => {
        exec(exec_cmd, (error, stdout, stderr) => {
            if (error) {
                return reject(error.message);
            };
            if (stderr) {
                return reject(stderr);
            };

            return resolve(stdout);
        });
    });
};

const validateSettings = () => {
    if (!(argv.stage === "dev" || argv.stage === "prod")) {
        throw new Error('Missing valid argument --stage [dev, prod]');
    };

    if (!process.env.DAD_SLACK_CHANNEL && !argv.slackChannel) {
        throw new Error('Missing valid environment variable: DAD_SLACK_CHANNEL or url --slackChannel');
    };

    if (!process.env.DAD_TEAM_NAME && !argv.teamName) {
        throw new Error('Missing valid environment variable: DAD_TEAM_NAME or param --teamName');
    };

    if (!process.env.DAD_URL_DEV) {
        throw new Error('Missing valid environment variable: DAD_URL_DEV');
    };

    if (!process.env.DAD_URL_PROD) {
        throw new Error('Missing valid environment variable: DAD_URL_PROD');
    };

    return;
};

validateSettings();

publish()
    .then((res) => console.log('Done sending deployment information to PN DAD'))
    .catch((err) => console.error(err.message));



